---
title: "Pambda.fr: Choisissez un format de fichier pour vos écrits"
author: 'Joseph Lucas'
date: '2021-11-18'
description: 'Pour chaque format de fichier (markdown, docx, odt et html) des éditeurs compatibles sont comparés (Microsoft Word, Zettlr, Open Office, etc).'
keywords: 'Pambda, Pambda.fr, Comparaison, , Tutorial, Howto, Editeur de Texte, Logiciel, Traitement de Texte, docx, odt, markdown, LibreOffice, Microsoft Word, OpenOffice, Zettlr, Typora, Pandoc'
header-includes: |
    <meta property="og:title" content="Pambda.fr: Choisissez un format de fichier pour vos écrits" />
    <meta property="og:type" content="website" />
    <meta property="og:description" content="Pour chaque format de fichier (markdown, docx, odt et html) des éditeurs compatibles sont comparés (Microsoft Word, Zettlr, Libre Office, etc)." />
    <meta property="og:url" content="https://pambda.fr/Blog/choose-a-file-format-and-a-word-processor-for-your-writings.html" />
    <meta property="og:image" content="https://pambda.fr/Blog/choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.png" />
    <meta property="og:image:type" content="image/png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="528" />
    <meta property="og:image:alt" content="Pambda" />
    <meta property="og:locale" content="en_US" />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:image" content="https://pambda.fr/Blog/choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.png">
    <style>
      li li > p:first-child {margin-top: 0 !important;}
      li li > p:last-child {margin-bottom: 0 !important;}
      /* TODO : https://tympanus.net/codrops/2012/11/02/heading-set-styling-with-css/ */
      /* Inspired by https://css-tricks.com/3-styles-for-big-headers/ */
      h1 {
        font-family: 'Linux Libertine','Georgia','Times',serif;
        font-size: 2.5em;
        letter-spacing: -1px;
      }
      /* Inspired by wikipedia article css*/
      h2 {
        font-size: 1.8em;
        padding: 0;
        font-family: 'Linux Libertine','Georgia','Times',serif;
        line-height: 1.3;
        border-bottom-color: rgb(91, 90, 86);
        border-bottom: 1px solid currentColor;
      }
    </style>
...

# Choisissez un format de fichiers pour vos écrits

![Des formats de fichiers et des éditeurs correspondants](choose-a-file-format-and-a-word-processor-for-your-writings/choose-a-format-and-a-word-processor.svg "Choisissez l'éditeur de texte et le format de vos fichiers"){width="50%"}

## Le format Markdown

Le format markdown est bien connu dans la communauté [STEM](https://fr.wikipedia.org/wiki/STEM_(disciplines)).
Le monde des lettres, pourrait grandement bénéficier de ce format de fichiers également.
En peu de mots, le format markdown vise à devenir le format de fichiers le plus léger pour du texte formaté, tout en préservant de multiples possibilités de mise en forme.

> Nous vous invitons à lire cet excellent tutoriel sur les fonctionnalités basiques des fichiers markdown : [Élaboration et conversion de documents avec Markdown et Pandoc](https://enacit.epfl.ch/cours/markdown-pandoc/).

La syntaxe de base des fichiers markdown est souvent étendue avec de nouvelles fonctionnalités.
La syntaxe, avec ces nouveautés, est ce qu'on appelle souvent une "flavor" (en français, une variation) du markdown.

### Éditeurs

Un simple éditeur de texte suffit pour éditer des fichiers markdown, mais un éditeur spécialisé vous facilitera la tâche.

- [Zettlr](https://www.zettlr.com/) est un programme gratuit et open source qui a une interface [WYSIWYM](https://fr.wikipedia.org/wiki/What_you_see_is_what_you_mean) puissante et [une documentation bien écrite et traduite en Français !](https://docs.zettlr.com/fr/)
- [Typora](https://typora.io/) est un éditeur gratuit et épuré. Cependant, Typora a une conception stricte de la variation de markdown : p. ex., [la syntaxe simple](https://pandoc.org/MANUAL.html#tables) pour les tables n'est pas forcément très bien supportée.

> Nous vous invitons à regarder cette [comparaison de Zettlr avec d'autres éditeurs de Markdown populaires](https://www.zettlr.com/features).
> Vous pouvez également lire [cette autre comparaison](https://www.slant.co/versus/2813/31650/~typora_vs_zettlr){rel="nofollow"}.

- [Visual Studio Code](https://code.visualstudio.com/) est un logiciel libre et open source. Bien que Visual Studio Code soit principalement connu pour être un logiciel de programmeur, avec l'extension [Markdown All in One](https://marketplace.visualstudio.com/items?itemName=yzhang.markdown-all-in-one) il offre une édition plaisante et efficace des fichiers markdown.


### Variation du format markdown et éditeur utilisés

Nous utilisons la variation de markdown pandoc, une variation très répandue.
La syntaxe de cette variation est expliquée en détail dans [le fichier d'exemple](https://input.pambda.fr/Documentation/markdown-formatting.md).

Nous vous guidons dans l'usage de Zettr et Visual Studio Code pour l'édition de vos fichiers markdown.

![Choix](choose-a-file-format-and-a-word-processor-for-your-writings/selection.svg "Choisissez le format de fichiers qui convient le mieux à vos compétences et à votre projet"){width="50%"}

## Le format docx

Il semble que les fichiers docx soient les fichiers les plus courants pour écrire des documents avec du texte structuré.

> Microsoft a sorti le format docx en même temps que Microsoft Word 2007. L'acronyme docx signifie "*doc* e*x*tension".
> Le format docx est officiellement le successeur du format _doc_, utilisé dans les précédentes versions de Microsoft Word, depuis les années 1997.
> Il est [courant](https://en.wikipedia.org/wiki/Office_Open_XML#Standardization_process) d'entendre dire que Microsoft a créé le format docx pour se protéger contre le format odt -- qui menaçait le monopole de Microsoft Word.
> Quand le format docx est arrivé, il était supposé suivre la norme [OOXML](https://fr.wikipedia.org/wiki/Office_Open_XML), mais Microsoft a continuellement fait évoluer son format de fichiers pour ajouter des fonctionnalités avancées.

### Éditeurs

Les fichiers docx sont habituellement édités avec le logiciel payant et propriétaire, Microsoft Word.
Mais d'autres éditeurs gratuits existent :

- [Open Office](https://fr.wikipedia.org/wiki/OpenOffice.org) a été le premier logiciel libre à concurrencer substantiellement Microsoft Word.
- [LibreOffice](https://fr.wikipedia.org/wiki/LibreOffice) est le successeur d'OpenOffice et est [recommandé par l'administration française](https://sill.etalab.gouv.fr/en/software?id=78) depuis plusieurs années.

> LibreOffice et OpenOffice prennent en charge les fichiers docx qui suivent la norme OOXML. Malheureusement les docx de Microsoft divergent continuellement de cette norme. Par conséquent, si vous utilisez LibreOffice ou OpenOffice pour ouvrir des fichiers docx créés avec Microsoft Word, vous pouvez voir des bizarreries lorsque des fonctionnalités avancées de mise en page sont affichées.

- [OnlyOffice](https://www.onlyoffice.com/fr/) [gère la norme OOXML de manière native](https://www.onlyoffice.com/blog/2018/08/onlyoffice-vs-libreoffice-what-to-choose-when-you-decide-to-ditch-microsoft) à la différence de LibreOffice et OpenOffice. OnlyOffice est donc théoriquement plus compatible avec les fichiers docx provenant de Microsoft Word. L'inconvénient, c'est que cela rend OnlyOffice moins compatible avec les fichiers odt créés avec LibreOffice et OpenOffice.
- [WPS](https://www.wps.com/) est le concurrent chinois de Microsoft Word. 
  C'est un logiciel propriétaire, mais gratuit.
  
![Fonts](choose-a-file-format-and-a-word-processor-for-your-writings/font.svg "Choisissez le logiciel de traitement de texte qui vous aidera à écrire efficacement"){width="50%"}

### Version du format docx et éditeur utilisés

Nous nous assurons que, les fichiers docx écrits avec LibreOffice, fonctionnent correctement avec nos services.
Durant notre service après-vente nous vous assistons avec LibreOffice.
Les fichiers docx, écrits avec Microsoft Word, fonctionnent correctement avec nos services également.

## Le format odt

Faisant partie de la norme [Open Document Formats (ODF)](https://fr.wikipedia.org/wiki/OpenDocument), le format odt a été créé autour de 2006, juste avant le format docx.
Le format odt est un format open source et a été créé pour faciliter les échanges de fichiers entre logiciels de traitement de texte.
Malheureusement, au moins jusqu'en 2018, [le format odt semble encore bien moins utilisé que le format docx](https://www.onlyoffice.com/blog/2018/09/format-race-2018-docx-over-doc-and-odt/).

### Éditeur Utilisé

Open source et stable, le format odt est largement supporté par la plupart des logiciels de traitement de texte.
Cependant, des versions de Microsoft Word et d'OnlyOffice [sont connues](https://linuxfr.org/users/jbf/journaux/onlyoffice-triche-avec-les-fichiers-opendocument) pour ne pas bien fonctionner avec le format odt.

Nous vous accompagnons avec LibreOffice pour l'édition des fichiers odt.

## Le format HTML

Si vous connaissez le langage HTML, vous pouvez écrire directement vos pages web en HTML.
Cela vous donnera un contrôle absolu sur le contenu et l'organisation de votre page.
Visual Studio Code est une interface de développement très agréable pour éditer des pages html.
